import React$1 from 'react';

/**
 * Types for the PDF.js viewer library
 */
interface PDFDocumentProxy {
    numPages: number;
    getPage: (pageNumber: number) => Promise<PDFPageProxy>;
}
interface PDFPageProxy {
    getViewport: (options: {
        scale: number;
    }) => PDFViewport;
    render: (renderContext: PDFRenderContext) => PDFRenderTask;
}
interface PDFViewport {
    width: number;
    height: number;
}
interface PDFRenderContext {
    canvasContext: CanvasRenderingContext2D;
    viewport: PDFViewport;
}
interface PDFRenderTask {
    promise: Promise<void>;
}
interface PDFJSLib {
    getDocument: (url: string) => {
        promise: Promise<PDFDocumentProxy>;
    };
    GlobalWorkerOptions: {
        workerSrc: string;
    };
}
interface PDFJSViewerProps {
    /**
     * URL of the PDF to display
     */
    pdfUrl: string;
    /**
     * Scale factor for rendering the PDF (default: 1.5)
     */
    scale?: number;
    /**
     * Custom renderer for navigation controls
     * @param props Navigation control props
     * @returns React element
     */
    renderControls?: (props: PDFControlsProps) => React.ReactNode;
    /**
     * CSS class name for the container
     */
    className?: string;
    /**
     * Worker source URL (default: Mozilla CDN)
     */
    workerSrc?: string;
}
interface PDFControlsProps {
    /**
     * Current page number
     */
    currentPage: number;
    /**
     * Total number of pages
     */
    totalPages: number;
    /**
     * Go to previous page
     */
    onPrevPage: () => void;
    /**
     * Go to next page
     */
    onNextPage: () => void;
    /**
     * Whether the previous button is disabled
     */
    isPrevDisabled: boolean;
    /**
     * Whether the next button is disabled
     */
    isNextDisabled: boolean;
}

/**
 * Default PDF controls component
 * @param props Control props
 * @returns React element
 */
declare const PDFControls: React.FC<PDFControlsProps>;

/**
 * PDF.js Viewer Component
 * A React component for viewing PDF documents using PDF.js
 */
declare const PDFJSViewer: React$1.FC<PDFJSViewerProps>;

export { PDFControls, type PDFControlsProps, type PDFDocumentProxy, type PDFJSLib, PDFJSViewer, type PDFJSViewerProps, type PDFPageProxy, type PDFRenderContext, type PDFRenderTask, type PDFViewport };
